@@ -22,7 +22,7 @@ pub fn from_graph(graph: &Graph, curved: bool) -> Result<String> {
                 )
                 .as_str(),
             ),
-            GraphNodeType::Node => res.push_str(
+            GraphNodeType::Node(_) => res.push_str(
                 format!(
                     "D{} [shape=box, label=\"{}\"];\n",
                     i.id,
@@ -30,7 +30,7 @@ pub fn from_graph(graph: &Graph, curved: bool) -> Result<String> {
                 )
                 .as_str(),
             ),
-            GraphNodeType::Choice => res.push_str(
+            GraphNodeType::Choice(_, _) => res.push_str(
                 format!(
                     "D{} [shape=diamond, label=\"{}?\"];\n",
                     i.id,
@@ -46,15 +46,15 @@ pub fn from_graph(graph: &Graph, curved: bool) -> Result<String> {
                 res.push_str(format!("D{}:s -> D{}:n;\n", i.id, i.id + 1).as_str());
             }
             GraphNodeType::End => res.push_str("}\n"),
-            GraphNodeType::Node => match i.jump {
+            GraphNodeType::Node(t) => match t {
                 Some(id) => res.push_str(format!("D{} -> D{};\n", i.id, id).as_str()),
                 None => res.push_str(format!("D{}:s-> D{}:n;\n", i.id, i.id + 1).as_str()),
             },
-            GraphNodeType::Choice => {
-                res.push_str(format!("D{}:s -> D{}:n [xlabel=Y];\n", i.id, i.id + 1).as_str());
+            GraphNodeType::Choice(t, f) => {
                 res.push_str(
-                    format!("D{}:e -> D{}:n [xlabel=N];\n", i.id, i.jump.unwrap()).as_str(),
+                    format!("D{}:s -> D{}:n [xlabel=Y];\n", i.id, t.unwrap_or(i.id + 1)).as_str(),
                 );
+                res.push_str(format!("D{}:e -> D{}:n [xlabel=N];\n", i.id, f.unwrap()).as_str());
             }
         }
     }
