@@ -4,10 +4,11 @@ mod ast;
 mod dot;
 mod graph;
 mod parser;
+mod tikz;
 
 fn main() -> anyhow::Result<()> {
     let matches = clap_app!(cxx2flow =>
-        (version: "0.1.6")
+        (version: "0.3.0")
         (author: "mgt. <mgt@oi-wiki.org>")
         (about: "Convert your C/C++ code to control flow chart")
         (@arg OUTPUT: -o --output +takes_value "Sets the output file.
@@ -15,6 +16,7 @@ If not specified, result will be directed to stdout.
 e.g. graph.dot")
         (@arg curved: -c --curved "Sets the style of the flow chart.
 If specified, output flow chart will have curved connection line.")
+        (@arg tikz: -t --tikz "Use tikz backend.")
         (@arg INPUT: +required "Sets the input file. e.g. test.cpp")
         (@arg FUNCTION: "The function you want to convert. e.g. main")
     )
@@ -28,13 +30,20 @@ EXAMPLES:
     let func = matches.value_of("FUNCTION").map(|x| x.to_string());
     let output = matches.value_of("OUTPUT");
     let curved = matches.is_present("curved");
-    let ast_vec = parser::parse(path, func)?;
-    let graph = graph::from_ast(ast_vec)?;
-    let dot = dot::from_graph(&graph, curved)?;
-    if let Some(output) = output {
-        std::fs::write(output, dot)?;
+    let tikz = matches.is_present("tikz");
+    let (ast_vec, maxid) = parser::parse(path, func)?;
+    // dbg!(&ast_vec);
+    let graph = graph::from_ast(ast_vec, maxid)?;
+    // dbg!(&graph);
+    let res = if tikz {
+        tikz::from_graph(&graph, curved)
     } else {
-        print!("{}", dot);
+        dot::from_graph(&graph, curved)
+    }?;
+    if let Some(output) = output {
+        std::fs::write(output, res)?;
+    } else {
+        print!("{}", res);
     }
     Ok(())
 }
